@@ -11,11 +11,17 @@ class Settings:
         self.nx = 401
         self.ny = 401
         self.eps = 1e-7
-        self.nt = int(7 / self.dt)
-        self.outfreq = int(1 / self.dt)
         self.lx0 = 2
         self.ly0 = 1
         self.options = Options(
             nonoscillatory=True,
             infinite_gauge=True
         )
+
+    @property
+    def nt(self):
+        return int(7 / self.dt)
+
+    @property
+    def outfreq(self):
+        return int(1 / self.dt)
