@@ -1,7 +1,22 @@
 from matplotlib import pyplot
 import numpy as np
 import matplotlib
-from .distributions import n_n
+
+
+def to_n_n(y, _, __):
+    return y
+
+
+def to_n_s(y, r1, r2):
+    return y * (r2 ** 2 + r1 ** 2 + r1 * r2) * 4 / 3 * np.pi
+
+
+def to_n_v(y, r1, r2):
+    return y * (r2 + r1) * (r2 ** 2 + r1 ** 2) / 4 * 4 / 3 * np.pi
+
+
+def from_n_n(n_n, _):
+    return 1 * n_n
 
 
 class Plotter:
@@ -26,23 +41,26 @@ class Plotter:
             self.axs = (self.axs,)
         self.fig.tight_layout(pad=5.0)
         self.style_dict = {}
-        self.style_palette = ['-','-', '-', '-', '-.']
+        self.style_palette = ['-', '-', '-', '-', '-.']
 
         self.settings.si.setup_matplotlib()
 
         if 'n' in plots:
-            self.axs[plots.index('n')].yaxis.set_units(1 / self.settings.si.micrometre / self.settings.si.centimetre ** 3)
+            self.axs[plots.index('n')].yaxis.set_units(
+                1 / self.settings.si.micrometre / self.settings.si.centimetre ** 3)
         if 'm' in plots:
-            self.axs[plots.index('m')].yaxis.set_units(1 / self.settings.si.micrometre)
+            self.axs[plots.index('m')].yaxis.set_units(
+                1 / self.settings.si.micrometre)
 
         for i in range(len(plots)):
             self.axs[i].xaxis.set_units(self.settings.si.micrometre)
             self.axs[i].grid()
+            self.axs[i].set_xlabel('particle radius [$μm$]')
 
         if 'm' in plots:
-            self.axs[plots.index('m')].set_title('$(dM/dr)/M$')
+            self.axs[plots.index('m')].set_ylabel('(dM/dr)/M [$μm^{-1}$]')
         if 'n' in plots:
-            self.axs[plots.index('n')].set_title('$dN/dr$')
+            self.axs[plots.index('n')].set_ylabel('dN/dr [$cm^{-3} μm^{-1}$]')
 
     def pdf_curve(self, pdf, mnorm, color='black'):
         x = self.cdfarg
@@ -71,7 +89,8 @@ class Plotter:
             )
         self.xlim(index)
 
-    def pdf_histogram(self, x, y, bin_boundaries, label, mnorm, color='black', linewidth = 1, fill=True):
+    def pdf_histogram(self, x, y,
+                      bin_boundaries, label, mnorm, color='black', linewidth = 1, fill=True):
         r1 = bin_boundaries[:-1]
         r2 = bin_boundaries[1:]
 
@@ -83,14 +102,16 @@ class Plotter:
 
         # number distribution
         if 'n' in self.plots:
-            self._plot('n', x, n_n.to_n_n(y, r1, r2), fill=fill, lbl=lbl, color=color, linewidth=linewidth)
+            self._plot('n', x, to_n_n(y, r1, r2),
+                       fill=fill, lbl=lbl, color=color, linewidth=linewidth)
 
         # normalised mass distribution
         if 'm' in self.plots:
-            self._plot('m', x, n_n.to_n_v(y, r1, r2) * self.settings.rho_w / self.settings.rho_a / mnorm, fill=fill, color=color, linewidth=linewidth, lbl=lbl)
+            self._plot('m', x,
+                       to_n_v(y, r1, r2) * self.settings.rho_w / self.settings.rho_a / mnorm,
+                       fill=fill, color=color, linewidth=linewidth, lbl=lbl)
 
     def xlim(self, plot):
         self.axs[self.plots.index(plot)].set_xlim(
             (0, self.settings.r_max.magnitude)
         )
-
