@@ -5,10 +5,10 @@ from PyMPDATA.boundary_conditions import Constant
 
 class Simulation:
     def __init__(self, settings, options, static=True):
-        bcs = tuple([Constant(0) for _ in settings.grid])
+        bcs = tuple(Constant(0) for _ in settings.grid)
 
         advector = VectorField(
-            data=[comp.astype(options.dtype) for comp in settings.advector],
+            data=tuple(comp.astype(options.dtype) for comp in settings.advector),
             halo=options.n_halo,
             boundary_conditions=bcs
         )
@@ -25,3 +25,7 @@ class Simulation:
 
     def run(self, nt):
         _ = self.solver.advance(nt)
+
+    @property
+    def advectee(self):
+        return self.solver.advectee
